@@ -3,8 +3,8 @@
  * rum.h
  *	  Exported definitions for RUM index.
  *
- * Portions Copyright (c) 2015-2019, Postgres Professional
- * Portions Copyright (c) 2006-2016, PostgreSQL Global Development Group
+ * Portions Copyright (c) 2015-2022, Postgres Professional
+ * Portions Copyright (c) 2006-2022, PostgreSQL Global Development Group
  *
  *-------------------------------------------------------------------------
  */
@@ -415,7 +415,7 @@ extern bytea *rumoptions(Datum reloptions, bool validate);
 extern bool rumproperty(Oid index_oid, int attno,
 			 IndexAMProperty prop, const char *propname,
 			 bool *res, bool *isnull);
-extern Datum rumhandler(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rumhandler(PG_FUNCTION_ARGS);
 extern void initRumState(RumState * state, Relation index);
 extern Buffer RumNewBuffer(Relation index);
 extern void RumInitBuffer(GenericXLogState *state, Buffer buffer, uint32 flags,
@@ -836,16 +836,16 @@ extern RumItem *rumGetBAEntry(BuildAccumulator *accum,
 #define RUM_ADDINFO_JOIN			10
 #define RUMNProcs					10
 
-extern Datum rum_extract_tsvector(PG_FUNCTION_ARGS);
-extern Datum rum_extract_tsquery(PG_FUNCTION_ARGS);
-extern Datum rum_tsvector_config(PG_FUNCTION_ARGS);
-extern Datum rum_tsquery_pre_consistent(PG_FUNCTION_ARGS);
-extern Datum rum_tsquery_distance(PG_FUNCTION_ARGS);
-extern Datum rum_ts_distance_tt(PG_FUNCTION_ARGS);
-extern Datum rum_ts_distance_ttf(PG_FUNCTION_ARGS);
-extern Datum rum_ts_distance_td(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_extract_tsvector(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_extract_tsquery(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_tsvector_config(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_tsquery_pre_consistent(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_tsquery_distance(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_ts_distance_tt(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_ts_distance_ttf(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_ts_distance_td(PG_FUNCTION_ARGS);
 
-extern Datum tsquery_to_distance_query(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum tsquery_to_distance_query(PG_FUNCTION_ARGS);
 
 /* rum_arr_utils.c */
 typedef enum SimilarityType
@@ -858,19 +858,19 @@ typedef enum SimilarityType
 #define RUM_SIMILARITY_FUNCTION_DEFAULT		SMT_COSINE
 #define RUM_SIMILARITY_THRESHOLD_DEFAULT	0.5
 
-extern Datum rum_anyarray_config(PG_FUNCTION_ARGS);
-extern Datum rum_extract_anyarray(PG_FUNCTION_ARGS);
-extern Datum rum_extract_anyarray_query(PG_FUNCTION_ARGS);
-extern Datum rum_anyarray_consistent(PG_FUNCTION_ARGS);
-extern Datum rum_anyarray_ordering(PG_FUNCTION_ARGS);
-extern Datum rum_anyarray_similar(PG_FUNCTION_ARGS);
-extern Datum rum_anyarray_distance(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_anyarray_config(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_extract_anyarray(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_extract_anyarray_query(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_anyarray_consistent(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_anyarray_ordering(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_anyarray_similar(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum rum_anyarray_distance(PG_FUNCTION_ARGS);
 
 
 /* GUC parameters */
-extern PGDLLIMPORT int		RumFuzzySearchLimit;
-extern PGDLLIMPORT float8	RumArraySimilarityThreshold;
-extern PGDLLIMPORT int		RumArraySimilarityFunction;
+extern int		RumFuzzySearchLimit;
+extern float8	RumArraySimilarityThreshold;
+extern int		RumArraySimilarityFunction;
 
 
 /*
