@@ -172,7 +172,7 @@ typedef struct
 	DocRepresentation *end;
 } Extention;
 
-static float weights[] = {1.0/0.1f, 1.0/0.2f, 1.0/0.4f, 1.0/1.0f};
+static float weights[] = {1.0f/0.1f, 1.0f/0.2f, 1.0f/0.4f, 1.0f/1.0f};
 
 /* A dummy WordEntryPos array to use when haspos is false */
 static WordEntryPosVector POSNULL = {
@@ -284,7 +284,14 @@ checkcondition_rum(void *checkval, QueryOperand *val, ExecPhraseData *data)
 		 * addInfo
 		 */
 		if (gcv->recheckPhrase)
-			return ((val->weight) ? TS_MAYBE : TS_YES);
+		{
+			/*
+			 * We cannot return TS_YES here (if "val->weight > 0"), because
+			 * data->npos = 0 and we have incorrect porocessing of this result
+			 * at the upper levels. So return TS_MAYBE.
+			 */
+			return TS_MAYBE;
+		}
 
 		positions = DatumGetByteaP(gcv->addInfo[j]);
 		ptrt = (char *) VARDATA_ANY(positions);
