@@ -7,7 +7,7 @@
  * It contains copy of static functions from
  * src/backend/utils/sort/tuplesort.c.
  *
- * Portions Copyright (c) 2015-2019, Postgres Professional
+ * Portions Copyright (c) 2015-2021, Postgres Professional
  * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -25,7 +25,7 @@
 /* RumTuplesortstate is an opaque type whose details are not known outside
  * rumsort.c.
  */
-typedef struct RumTuplesortstate RumTuplesortstate;
+typedef struct Tuplesortstate RumTuplesortstate;
 struct RumScanItem;
 
 typedef struct
@@ -38,7 +38,6 @@ typedef struct
 #define RumSortItemSize(nKeys) (offsetof(RumSortItem,data)+(nKeys)*sizeof(float8))
 
 extern MemoryContext rum_tuplesort_get_memorycontext(RumTuplesortstate *state);
-
 extern RumTuplesortstate *rum_tuplesort_begin_rum(int workMem,
 						int nKeys, bool randomAccess, bool compareItemPointer);
 extern RumTuplesortstate	*rum_tuplesort_begin_rumitem(int workMem,
@@ -56,6 +55,4 @@ extern struct RumScanItem *rum_tuplesort_getrumitem(RumTuplesortstate *state, bo
 
 extern void rum_tuplesort_end(RumTuplesortstate *state);
 
-extern int	rum_tuplesort_merge_order(long allowedMem);
-
 #endif   /* RUMSORT_H */
